import QtQuick 2.9
import QtQuick.Layouts 1.1
import QtQuick.Controls 2.5
import org.kde.plasma.core 2.0

Item {
    id:root

    Item {
    id: wData
     Component.onCompleted: {
        getWeather(url2)
        getWeather(url3)
    }
    property var url2:"/tmp/weather.json"
    property var url3: "/tmp/forecast.json"

    property var weather:{}
    property var forecast:{}

    property var codes:{0:"weather-tornado",1:"weather-storm",2:"weather-storm",3:"weather-storm",4:"weather-storm",5:"weather-snow",6:"weather-snow,",7:"weather-snow-rain",8:"weather-freezing-rain",9:"weather-freezing-rain",10:"weather-freezing-rain",11:"weather-showers-scattered",12:"weather-showers-scattered",13:"weather-snow",14:"weather-snow",15:"weather-snow",16:"weather-snow",17:"weather-hail",18:"weather-freezing-rain",19:"weather-fog",20:"weather-fog",21:"weather-fog",22:"weather-fog",23:"weather-clouds-wind",24:"weather-clouds-wind",25:"weather-freezing-rain",26:"weather-overcast",27:"weather-clouds-night",28:"weather-clouds",29:"weather-few-clouds-night",30:"weather-few-clouds",31:"weather-clear-night",32:"weather-clear",33:"weather-clear-night",34:"weather-clear",35:"weather-freezing-rain",36:"weather-clear",37:"weather-storm",38:"weather-storm",39:"weather-showers-scattered",40:"weather-storm",41:"weather-snow-scattered-day",42:"weather-snow",43:"weather-snow",44:"edit-none",45:"weather-showers-scattered-night",46:"weather-snow-scattered-night",47:"weather-storm-night"}


    property var iconCode1:codes[weather.iconCode]

    //property var iconCode1:codes[34]
    property double startTime: 0
    property int secondsElapsed: 0

    function timeChanged() {
        if(root.startTime==0)
        {
            root.startTime = new Date().getTime(); //returns the number of milliseconds since the epoch (1970-01-01T00:00:00Z);
        }
        var currentTime = new Date().getTime();
        root.secondsElapsed = (currentTime-startTime)/1000;
    }

    function getWeather(url){  // read weather icon code from file
        var xhr = new XMLHttpRequest;
        xhr.open("GET", url); // set Method and File
        xhr.onreadystatechange = function () {
            if(xhr.readyState === XMLHttpRequest.DONE){ // if request_status == DONE
                var response = xhr.responseText;
                if (url===url2) {
                weather = JSON.parse(response)}
                else if (url===url3) {
                    forecast = JSON.parse(response)}
            }
        }
        xhr.send(); // begin the request
    }

    Timer{                  // timer to trigger update for weather info
        id: updateWeather
        interval: 20 * 60 * 1000 // every 20 minutes
        running: true
        repeat:  true
        onTriggered: {
            root.startTime=0  // restart counter since last update
            getWeather(url2)
            getWeather(url3)
            radar.source=""
            radar.source="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg"
        }
    }

    Timer{                  // timer to trigger update after wake from suspend mode
        id: suspend
        interval: 60*1000 ///delay 60 secs for suspend to resume
        running: true
        repeat:  true
        onTriggered: {
            root.timeChanged()
            if (root.secondsElapsed > 1500) {
                getWeather(url2)
                getWeather(url3)
                radar.source=""
                radar.source="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg"
            }
        }
}
}

  Text {
      text:"Last update: "+Qt.formatTime(wData.weather.validTimeLocal,"h:mm AP")
      color:"gray"
      font.pointSize:10
      x:320
      y:root.top
  }

Row {
    id:conditions
    anchors.top:root.top
    anchors.left:root.left

Image {
    id:iconCode
    source:"../icons/"+wData.weather.iconCode+".png"
    width:72
    height:72
    y:5
    }

Text {
        id:temp
        anchors.left:iconCode.right
        anchors.leftMargin:15
        y:12
        text:wData.weather.temperature+"°   "+wData.weather.wxPhraseLong
        color:Theme.textColor
        font.pointSize:18
    }
}


Text {
        id:story
        anchors.top:conditions.bottom
        text:wData.forecast.narrative[0]//+"<br>"+"Last update: "+Qt.formatTime(wData.weather.validTimeLocal,"h:mm AP")
        //wData.weather.validTimeLocale//Qt.formatDate(wData.weather.validTimeLocale["Local"]["DateTime"],"MMdd")
        wrapMode:Text.WordWrap
        x:80
        anchors.topMargin:50
        textFormat: Text.RichText
        Layout.fillWidth : true
        width:380
        color:Theme.textColor
        font.pointSize:12
}

Rectangle {
            id:ts
            anchors.top:story.bottom
            anchors.topMargin:10
            implicitWidth: root.width
            implicitHeight: 2
            color: "gray"
            antialiasing : true
            Layout.fillWidth: true
        }

Row {
    id:dayOfWeek
    anchors.leftMargin:55
    anchors.left:root.left
    anchors.top:ts.bottom
    anchors.topMargin:5
    spacing:40

    Text {id:d1;text:wData.forecast.dayOfWeek[1].replace("Sunday","SUN").replace("Saturday","SAT").replace("Monday","MON").replace("Tuesday","TUE").replace("Wednesday","WED").replace("Thursday","THU").replace("Friday","FRI");font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignHCenter;width:44;}
    //Text{text:" "}
    Text{id:d2;text:wData.forecast.dayOfWeek[2].replace("Sunday","SUN").replace("Saturday","SAT").replace("Monday","MON").replace("Tuesday","TUE").replace("Wednesday","WED").replace("Thursday","THU").replace("Friday","FRI");font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignHCenter;width:44;}
    //Text{text:" "}
    Text {id:d3;text:wData.forecast.dayOfWeek[3].replace("Sunday","SUN").replace("Saturday","SAT").replace("Monday","MON").replace("Tuesday","TUE").replace("Wednesday","WED").replace("Thursday","THU").replace("Friday","FRI");font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignHCenter;width:44;}
    //Text{text:" "}
    Text {id:d4;text:wData.forecast.dayOfWeek[4].replace("Sunday","SUN").replace("Saturday","SAT").replace("Monday","MON").replace("Tuesday","TUE").replace("Wednesday","WED").replace("Thursday","THU").replace("Friday","FRI");font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignHCenter;width:44;}
    //Text{text:" "}
    Text {id:d5;text:wData.forecast.dayOfWeek[5].replace("Sunday","SUN").replace("Saturday","SAT").replace("Monday","MON").replace("Tuesday","TUE").replace("Wednesday","WED").replace("Thursday","THU").replace("Friday","FRI");font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignHCenter;width:44;}

}

Row {
    id:icons
    anchors.top:dayOfWeek.bottom
    anchors.leftMargin:55
    spacing:50
    anchors.left:root.left
    Image {
            id:im1;
            source : "../icons/"+wData.forecast.daypart[0].iconCode[2]+".png"
            smooth: true
            sourceSize.width: 32
            sourceSize.height: 32
            Layout.alignment: Qt.AlignCenter
        }

    Image {
            id:im2;
            source : "../icons/"+wData.forecast.daypart[0].iconCode[4]+".png"
            smooth: true
            sourceSize.width: 32
            sourceSize.height: 32
            Layout.alignment: Qt.AlignCenter
        }
    Image {
            id:im3;
            source : "../icons/"+wData.forecast.daypart[0].iconCode[6]+".png"
            smooth: true
            sourceSize.width: 32
            sourceSize.height: 32
            Layout.alignment: Qt.AlignCenter
        }
    Image {
            id:im4;
            source : "../icons/"+wData.forecast.daypart[0].iconCode[8]+".png"
            smooth: true
            sourceSize.width: 32
            sourceSize.height: 32
            Layout.alignment: Qt.AlignCenter
        }
    Image {
            id:im6;
            source : "../icons/"+wData.forecast.daypart[0].iconCode[10]+".png"
            smooth: true
            sourceSize.width: 32
            sourceSize.height: 32
            Layout.alignment: Qt.AlignCenter
        }

}

Row {
    id:rainChances
    anchors.top:icons.bottom
    anchors.leftMargin:55
    spacing:50
    anchors.left:root.left
    Text { id:r1a;width:36;text: "  "+Math.round(wData.forecast.daypart[0].precipChance[2] / 10) * 10+"%";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType:Text.QtRendering;Layout.alignment: Qt.AlignCenter}
    //Text{text:" "}
     Text { id:r2a;text:" "+Math.round(wData.forecast.daypart[0].precipChance[4] / 10) * 10+"%";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType:Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignCenter}
    //Text{text:" "}
     Text { id:r3a;text:" "+Math.round(wData.forecast.daypart[0].precipChance[6] / 10) * 10+"%";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType:Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignCenter}
    //Text{text:" "}
     Text { id:r4a;text:" "+Math.round(wData.forecast.daypart[0].precipChance[8] / 10) * 10+"%";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType:Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignCenter}
    //Text{text:" "}
     Text { id:r5a;text: " "+Math.round(wData.forecast.daypart[0].precipChance[10] / 10) * 10+"%";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType:Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignHCenter}
}

Row {
    id:temps
    anchors.leftMargin:40
    spacing:10
    anchors.left:root.left
    anchors.top:rainChances.bottom
    Text { id:f1;text: wData.forecast.calendarDayTemperatureMin[1]+"°"+" | "+ wData.forecast.calendarDayTemperatureMax[1]+"°  ";font.pointSize:12;color: Theme.textColor;antialiasing : true}
    //Text{text:" "}
    Text { id:f2;text: wData.forecast.calendarDayTemperatureMin[2]+"°"+" | "+ wData.forecast.calendarDayTemperatureMax[2]+"°  ";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignCenter}
    //Text{text:" "}
    Text { id:f3;text: wData.forecast.calendarDayTemperatureMin[3]+"°"+" | "+ wData.forecast.calendarDayTemperatureMax[3]+"°  ";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignCenter}
    //Text{text:" "}
    Text { id:f4;text: wData.forecast.calendarDayTemperatureMin[4]+"°"+" | "+ wData.forecast.calendarDayTemperatureMax[4]+"°  ";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignCenter}
    //Text{text:" "}
    Text { id:f5;text: wData.forecast.calendarDayTemperatureMin[5]+"°"+" | "+ wData.forecast.calendarDayTemperatureMax[5]+"°";font.pointSize:12;color: Theme.textColor;antialiasing : true;renderType: Text.QtRendering;Layout.fillWidth : true;Layout.alignment: Qt.AlignCenter}
    }

    Column {
        id:radar_info
        anchors.top:temps.bottom
        anchors.topMargin:5
        anchors.left:root.left
       // Layout.alignment : Qt.AlignmentBottom
        spacing:2

    Rectangle {
            id:ts2
            implicitWidth: root.width
            implicitHeight: 2
            Layout.fillWidth: true
            color: "gray"
            }

        Text {text:" ";font.pointSize:2}  //spacer
    Image {
        id:radar
        source:"https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg"
        smooth: true
        width: root.width
        //topPadding:10
        //height: (conditions.height+story.height+dayOfWeek.height+rainChances.height+temps.height)*2.10
        //anchors.topMargin:20
        fillMode:Image.PreserveAspectFit

        MouseArea {
            anchors.fill: parent
            acceptedButtons: Qt.LeftButton | Qt.MiddleButton
            hoverEnabled: true
            cursorShape:Qt.PointingHandCursor
            onClicked: {
                 Qt.openUrlExternally("https://abc13.com/weather/")
            }
        }
     }
    }
}
