import QtQuick 2.9
import org.kde.plasma.core 2.1

Item {
    id: wData

    //property string url2:"https://api.darksky.net/forecast/522dc5d7c682775779e3e83d68fd0161/29.69,-95.04?exclude=minutely,flags"
    property string url2: "/tmp/weather.json";  // causing warning, if get from https:// no warning ...?
    property var weather:{};
    property string radarImage:"SETX1_1280.jpg";
    property var last_update:"12:34 pm";
    property bool warnings:false;
    property string alert_text: "";
    property double startTime: 0;
    property int secondsElapsed: 0;


    function getWeather(url){  // read weather icon code from file
      var xhr = new XMLHttpRequest();
      xhr.open("GET", url,false); // set Method and File
      xhr.onreadystatechange = function () {
         if(xhr.readyState === XMLHttpRequest.DONE){ // if request_status == DONE
            var response = xhr.responseText;
                weather = JSON.parse(response);
                last_update=Qt.formatTime(new Date(weather.currently.time*1000))
                warnings=weather.hasOwnProperty("alerts") ? true:false // check if alert exists
                alert_text=warnings ? "⚠️   "+weather.alerts[0].title : ""
                response=null;
                xhr=null;
         }
      }
      xhr.send(); // begin the request
   }

     property var iconCode:{"clear-day": '\uf00d',
                            "clear-night": '\uf02e',
                            "rain":'\uf019',
                            "snow":'\uf01b',
                            "sleet":'\uf0b5',
                            "wind":'\uf021',
                            "fog": '\uf014',
                            "cloudy":'\uf013',
                            "partly-cloudy-day":'\uf002',
                            "partly-cloudy-night":'\uf031',
                            "hail":'\uf015',
                            "thunderstorm":'\uf01e',
                            "tornado":'\uf056'}

    function ozone_lvl(x) {  // levels not right need dobson units conversion

            if (x < 60)
                ozone="Good"
            else if ( x <  120)
                ozone="Fair"
            else if ( x < 180)
                ozone="Moderate"
            else if ( x < 240 )
                ozone="Poor"
            else if ( x > 240)
                ozone="Very Poor"
    }

        function  moon_icon(moon_phase) {
            if (moon_phase == 0)
                return "new_moon"
            if (moon_phase < .125)
                return "waxing_crescent_moon"
            if (moon_phase < .25)
                return "first_quarter_moon"
            if (moon_phase < .48)
                return "waxing_gibbous_moon"
            if (moon_phase < .52)
                return "full_moon"
            if (moon_phase < .625)
                return "waning_gibbous_moon"
            if (moon_phase < .75)
                return "last_quarter_moon"
            if (moon_phase < 1)
                return "waning_crescent_moon"
            return "crescent_moon"

        }

    function degToCompass(num) {
        var val = Math.floor((num / 22.5) + 0.5);
        var arr = ["N", "NNE", "NE", "ENE", "E", "ESE", "SE", "SSE", "S", "SSW", "SW", "WSW", "W", "WNW", "NW", "NNW"];
    return arr[(val % 16)];
}

function timeChanged() {  // checck if timer greater than normal timer 20 mins // wake from sleep mode test
        if(startTime==0) {
            startTime = new Date().getTime(); //returns the number of milliseconds since the epoch (1970-01-01T00:00:00Z);
        }
        var currentTime = new Date().getTime();
        secondsElapsed = (currentTime-startTime)/1000;
    return secondsElapsed
    }

property var updateWeatherTimer: Timer {                  // timer to trigger update for weather info
    id: weatherTimer
    interval: 20 * 60 * 1000 // every 20 minutes
    running: true
    repeat:  true
    triggeredOnStart:true
    onTriggered: {
        getWeather(url2);
        radarImage="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX2_1280.jpg";
        radarImage="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg";
        startTime=0;
    }
}

property var suspendTimer: Timer{       // timer to trigger update after wake from suspend mode
    id: suspend;
    interval: 20*1000;///delay 20 secs for suspend to resume
    running: false
    repeat:  false;
    onTriggered: {
            getWeather(url2);
            radarImage="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX2_1280.jpg";
            radarImage="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg";
            updateWeatherTimer.restart();
        }
}

DataSource {
        id: checkTimer
        engine: "time"
        connectedSources: ["Local"]
        interval: 900
        onNewData:(timeChanged()>1210) ?  suspendTimer.start():suspendTimer.stop()
        }
}
